/*
 * Copyright 2019 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.android.overtheair.spi.v1;

import com.google.android.overtheair.spi.v1.stub.OverTheAirServiceStubSettings;
import com.google.android.overtheair.v1.Chart;
import com.google.android.overtheair.v1.Config;
import com.google.android.overtheair.v1.CreateConfigRequest;
import com.google.android.overtheair.v1.CreateGroupMemberRequest;
import com.google.android.overtheair.v1.CreateGroupMembersRequest;
import com.google.android.overtheair.v1.CreateGroupMembersResponse;
import com.google.android.overtheair.v1.CreateGroupRequest;
import com.google.android.overtheair.v1.DeleteConfigRequest;
import com.google.android.overtheair.v1.DeleteConfigResponse;
import com.google.android.overtheair.v1.DeleteGroupMemberRequest;
import com.google.android.overtheair.v1.DeleteGroupMemberResponse;
import com.google.android.overtheair.v1.DeleteGroupMembersRequest;
import com.google.android.overtheair.v1.DeleteGroupMembersResponse;
import com.google.android.overtheair.v1.DeleteGroupRequest;
import com.google.android.overtheair.v1.DeleteGroupResponse;
import com.google.android.overtheair.v1.DeletePackageRequest;
import com.google.android.overtheair.v1.DeletePackageResponse;
import com.google.android.overtheair.v1.Deployment;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigRequest;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigResponse;
import com.google.android.overtheair.v1.DisableGroupsRequest;
import com.google.android.overtheair.v1.DisableGroupsResponse;
import com.google.android.overtheair.v1.EnableGroupsRequest;
import com.google.android.overtheair.v1.EnableGroupsResponse;
import com.google.android.overtheair.v1.GetConfigRequest;
import com.google.android.overtheair.v1.GetDeploymentRequest;
import com.google.android.overtheair.v1.GetGroupChartRequest;
import com.google.android.overtheair.v1.GetGroupMemberRequest;
import com.google.android.overtheair.v1.GetGroupRequest;
import com.google.android.overtheair.v1.GetPackageRequest;
import com.google.android.overtheair.v1.Group;
import com.google.android.overtheair.v1.GroupMember;
import com.google.android.overtheair.v1.ListConfigPackagesRequest;
import com.google.android.overtheair.v1.ListConfigPackagesResponse;
import com.google.android.overtheair.v1.ListConfigsRequest;
import com.google.android.overtheair.v1.ListConfigsResponse;
import com.google.android.overtheair.v1.ListConfigsUsingPackageRequest;
import com.google.android.overtheair.v1.ListConfigsUsingPackageResponse;
import com.google.android.overtheair.v1.ListDeploymentsRequest;
import com.google.android.overtheair.v1.ListDeploymentsResponse;
import com.google.android.overtheair.v1.ListGroupChartsRequest;
import com.google.android.overtheair.v1.ListGroupChartsResponse;
import com.google.android.overtheair.v1.ListGroupConfigsRequest;
import com.google.android.overtheair.v1.ListGroupConfigsResponse;
import com.google.android.overtheair.v1.ListGroupMembersRequest;
import com.google.android.overtheair.v1.ListGroupMembersResponse;
import com.google.android.overtheair.v1.ListGroupsRequest;
import com.google.android.overtheair.v1.ListGroupsResponse;
import com.google.android.overtheair.v1.ListPackagesRequest;
import com.google.android.overtheair.v1.ListPackagesResponse;
import com.google.android.overtheair.v1.UpdateConfigPackagesRequest;
import com.google.android.overtheair.v1.UpdateConfigPackagesResponse;
import com.google.android.overtheair.v1.UpdateConfigRequest;
import com.google.android.overtheair.v1.UpdateDeploymentRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsResponse;
import com.google.android.overtheair.v1.UpdateGroupRequest;
import com.google.android.overtheair.v1.UpdatePackageRequest;
import com.google.api.core.ApiFunction;
import com.google.api.core.BetaApi;
import com.google.api.gax.core.GoogleCredentialsProvider;
import com.google.api.gax.core.InstantiatingExecutorProvider;
import com.google.api.gax.grpc.InstantiatingGrpcChannelProvider;
import com.google.api.gax.rpc.ApiClientHeaderProvider;
import com.google.api.gax.rpc.ClientContext;
import com.google.api.gax.rpc.ClientSettings;
import com.google.api.gax.rpc.TransportChannelProvider;
import com.google.api.gax.rpc.UnaryCallSettings;
import java.io.IOException;
import java.util.List;
import javax.annotation.Generated;

// AUTO-GENERATED DOCUMENTATION AND CLASS
/**
 * Settings class to configure an instance of {@link OverTheAirServiceClient}.
 *
 * <p>The default instance has everything set to sensible defaults:
 *
 * <ul>
 *   <li>The default service address (androidovertheair.googleapis.com) and default port (443) are
 *       used.
 *   <li>Credentials are acquired automatically through Application Default Credentials.
 *   <li>Retries are configured for idempotent methods but not for non-idempotent methods.
 * </ul>
 *
 * <p>The builder of this class is recursive, so contained classes are themselves builders. When
 * build() is called, the tree of builders is called to create the complete settings object. For
 * example, to set the total timeout of getDeployment to 30 seconds:
 *
 * <pre>
 * <code>
 * OverTheAirServiceSettings.Builder overTheAirServiceSettingsBuilder =
 *     OverTheAirServiceSettings.newBuilder();
 * overTheAirServiceSettingsBuilder.getDeploymentSettings().getRetrySettings().toBuilder()
 *     .setTotalTimeout(Duration.ofSeconds(30));
 * OverTheAirServiceSettings overTheAirServiceSettings = overTheAirServiceSettingsBuilder.build();
 * </code>
 * </pre>
 */
@Generated("by gapic-generator")
@BetaApi
public class OverTheAirServiceSettings extends ClientSettings<OverTheAirServiceSettings> {
  /** Returns the object with the settings used for calls to getDeployment. */
  public UnaryCallSettings<GetDeploymentRequest, Deployment> getDeploymentSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getDeploymentSettings();
  }

  /** Returns the object with the settings used for calls to listDeployments. */
  public UnaryCallSettings<ListDeploymentsRequest, ListDeploymentsResponse>
      listDeploymentsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listDeploymentsSettings();
  }

  /** Returns the object with the settings used for calls to updateDeployment. */
  public UnaryCallSettings<UpdateDeploymentRequest, Deployment> updateDeploymentSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updateDeploymentSettings();
  }

  /** Returns the object with the settings used for calls to getPackage. */
  public UnaryCallSettings<GetPackageRequest, com.google.android.overtheair.v1.Package>
      getPackageSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getPackageSettings();
  }

  /** Returns the object with the settings used for calls to listPackages. */
  public UnaryCallSettings<ListPackagesRequest, ListPackagesResponse> listPackagesSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listPackagesSettings();
  }

  /** Returns the object with the settings used for calls to deletePackage. */
  public UnaryCallSettings<DeletePackageRequest, DeletePackageResponse> deletePackageSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).deletePackageSettings();
  }

  /** Returns the object with the settings used for calls to updatePackage. */
  public UnaryCallSettings<UpdatePackageRequest, com.google.android.overtheair.v1.Package>
      updatePackageSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updatePackageSettings();
  }

  /** Returns the object with the settings used for calls to createConfig. */
  public UnaryCallSettings<CreateConfigRequest, Config> createConfigSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).createConfigSettings();
  }

  /** Returns the object with the settings used for calls to getConfig. */
  public UnaryCallSettings<GetConfigRequest, Config> getConfigSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getConfigSettings();
  }

  /** Returns the object with the settings used for calls to listConfigs. */
  public UnaryCallSettings<ListConfigsRequest, ListConfigsResponse> listConfigsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listConfigsSettings();
  }

  /** Returns the object with the settings used for calls to deleteConfig. */
  public UnaryCallSettings<DeleteConfigRequest, DeleteConfigResponse> deleteConfigSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).deleteConfigSettings();
  }

  /** Returns the object with the settings used for calls to updateConfig. */
  public UnaryCallSettings<UpdateConfigRequest, Config> updateConfigSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updateConfigSettings();
  }

  /** Returns the object with the settings used for calls to createGroup. */
  public UnaryCallSettings<CreateGroupRequest, Group> createGroupSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).createGroupSettings();
  }

  /** Returns the object with the settings used for calls to getGroup. */
  public UnaryCallSettings<GetGroupRequest, Group> getGroupSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getGroupSettings();
  }

  /** Returns the object with the settings used for calls to listGroups. */
  public UnaryCallSettings<ListGroupsRequest, ListGroupsResponse> listGroupsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listGroupsSettings();
  }

  /** Returns the object with the settings used for calls to deleteGroup. */
  public UnaryCallSettings<DeleteGroupRequest, DeleteGroupResponse> deleteGroupSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).deleteGroupSettings();
  }

  /** Returns the object with the settings used for calls to updateGroup. */
  public UnaryCallSettings<UpdateGroupRequest, Group> updateGroupSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updateGroupSettings();
  }

  /** Returns the object with the settings used for calls to disableGroups. */
  public UnaryCallSettings<DisableGroupsRequest, DisableGroupsResponse> disableGroupsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).disableGroupsSettings();
  }

  /** Returns the object with the settings used for calls to enableGroups. */
  public UnaryCallSettings<EnableGroupsRequest, EnableGroupsResponse> enableGroupsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).enableGroupsSettings();
  }

  /** Returns the object with the settings used for calls to createGroupMember. */
  public UnaryCallSettings<CreateGroupMemberRequest, GroupMember> createGroupMemberSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).createGroupMemberSettings();
  }

  /** Returns the object with the settings used for calls to createGroupMembers. */
  public UnaryCallSettings<CreateGroupMembersRequest, CreateGroupMembersResponse>
      createGroupMembersSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).createGroupMembersSettings();
  }

  /** Returns the object with the settings used for calls to getGroupMember. */
  public UnaryCallSettings<GetGroupMemberRequest, GroupMember> getGroupMemberSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getGroupMemberSettings();
  }

  /** Returns the object with the settings used for calls to listGroupMembers. */
  public UnaryCallSettings<ListGroupMembersRequest, ListGroupMembersResponse>
      listGroupMembersSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listGroupMembersSettings();
  }

  /** Returns the object with the settings used for calls to deleteGroupMember. */
  public UnaryCallSettings<DeleteGroupMemberRequest, DeleteGroupMemberResponse>
      deleteGroupMemberSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).deleteGroupMemberSettings();
  }

  /** Returns the object with the settings used for calls to deleteGroupMembers. */
  public UnaryCallSettings<DeleteGroupMembersRequest, DeleteGroupMembersResponse>
      deleteGroupMembersSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).deleteGroupMembersSettings();
  }

  /** Returns the object with the settings used for calls to getGroupChart. */
  public UnaryCallSettings<GetGroupChartRequest, Chart> getGroupChartSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).getGroupChartSettings();
  }

  /** Returns the object with the settings used for calls to listGroupCharts. */
  public UnaryCallSettings<ListGroupChartsRequest, ListGroupChartsResponse>
      listGroupChartsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listGroupChartsSettings();
  }

  /** Returns the object with the settings used for calls to listGroupConfigs. */
  public UnaryCallSettings<ListGroupConfigsRequest, ListGroupConfigsResponse>
      listGroupConfigsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listGroupConfigsSettings();
  }

  /** Returns the object with the settings used for calls to updateGroupConfigs. */
  public UnaryCallSettings<UpdateGroupConfigsRequest, UpdateGroupConfigsResponse>
      updateGroupConfigsSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updateGroupConfigsSettings();
  }

  /** Returns the object with the settings used for calls to disableAllEnabledGroupsOfConfig. */
  public UnaryCallSettings<
          DisableAllEnabledGroupsOfConfigRequest, DisableAllEnabledGroupsOfConfigResponse>
      disableAllEnabledGroupsOfConfigSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings())
        .disableAllEnabledGroupsOfConfigSettings();
  }

  /** Returns the object with the settings used for calls to listConfigPackages. */
  public UnaryCallSettings<ListConfigPackagesRequest, ListConfigPackagesResponse>
      listConfigPackagesSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listConfigPackagesSettings();
  }

  /** Returns the object with the settings used for calls to updateConfigPackages. */
  public UnaryCallSettings<UpdateConfigPackagesRequest, UpdateConfigPackagesResponse>
      updateConfigPackagesSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).updateConfigPackagesSettings();
  }

  /** Returns the object with the settings used for calls to listConfigsUsingPackage. */
  public UnaryCallSettings<ListConfigsUsingPackageRequest, ListConfigsUsingPackageResponse>
      listConfigsUsingPackageSettings() {
    return ((OverTheAirServiceStubSettings) getStubSettings()).listConfigsUsingPackageSettings();
  }

  public static final OverTheAirServiceSettings create(OverTheAirServiceStubSettings stub)
      throws IOException {
    return new OverTheAirServiceSettings.Builder(stub.toBuilder()).build();
  }

  /** Returns a builder for the default ExecutorProvider for this service. */
  public static InstantiatingExecutorProvider.Builder defaultExecutorProviderBuilder() {
    return OverTheAirServiceStubSettings.defaultExecutorProviderBuilder();
  }

  /** Returns the default service endpoint. */
  public static String getDefaultEndpoint() {
    return OverTheAirServiceStubSettings.getDefaultEndpoint();
  }

  /** Returns the default service scopes. */
  public static List<String> getDefaultServiceScopes() {
    return OverTheAirServiceStubSettings.getDefaultServiceScopes();
  }

  /** Returns a builder for the default credentials for this service. */
  public static GoogleCredentialsProvider.Builder defaultCredentialsProviderBuilder() {
    return OverTheAirServiceStubSettings.defaultCredentialsProviderBuilder();
  }

  /** Returns a builder for the default ChannelProvider for this service. */
  public static InstantiatingGrpcChannelProvider.Builder defaultGrpcTransportProviderBuilder() {
    return OverTheAirServiceStubSettings.defaultGrpcTransportProviderBuilder();
  }

  public static TransportChannelProvider defaultTransportChannelProvider() {
    return OverTheAirServiceStubSettings.defaultTransportChannelProvider();
  }

  @BetaApi("The surface for customizing headers is not stable yet and may change in the future.")
  public static ApiClientHeaderProvider.Builder defaultApiClientHeaderProviderBuilder() {
    return OverTheAirServiceStubSettings.defaultApiClientHeaderProviderBuilder();
  }

  /** Returns a new builder for this class. */
  public static Builder newBuilder() {
    return Builder.createDefault();
  }

  /** Returns a new builder for this class. */
  public static Builder newBuilder(ClientContext clientContext) {
    return new Builder(clientContext);
  }

  /** Returns a builder containing all the values of this settings class. */
  public Builder toBuilder() {
    return new Builder(this);
  }

  protected OverTheAirServiceSettings(Builder settingsBuilder) throws IOException {
    super(settingsBuilder);
  }

  /** Builder for OverTheAirServiceSettings. */
  public static class Builder extends ClientSettings.Builder<OverTheAirServiceSettings, Builder> {
    protected Builder() throws IOException {
      this((ClientContext) null);
    }

    protected Builder(ClientContext clientContext) {
      super(OverTheAirServiceStubSettings.newBuilder(clientContext));
    }

    private static Builder createDefault() {
      return new Builder(OverTheAirServiceStubSettings.newBuilder());
    }

    protected Builder(OverTheAirServiceSettings settings) {
      super(settings.getStubSettings().toBuilder());
    }

    protected Builder(OverTheAirServiceStubSettings.Builder stubSettings) {
      super(stubSettings);
    }

    public OverTheAirServiceStubSettings.Builder getStubSettingsBuilder() {
      return ((OverTheAirServiceStubSettings.Builder) getStubSettings());
    }

    // NEXT_MAJOR_VER: remove 'throws Exception'
    /**
     * Applies the given settings updater function to all of the unary API methods in this service.
     *
     * <p>Note: This method does not support applying settings to streaming methods.
     */
    public Builder applyToAllUnaryMethods(
        ApiFunction<UnaryCallSettings.Builder<?, ?>, Void> settingsUpdater) throws Exception {
      super.applyToAllUnaryMethods(
          getStubSettingsBuilder().unaryMethodSettingsBuilders(), settingsUpdater);
      return this;
    }

    /** Returns the builder for the settings used for calls to getDeployment. */
    public UnaryCallSettings.Builder<GetDeploymentRequest, Deployment> getDeploymentSettings() {
      return getStubSettingsBuilder().getDeploymentSettings();
    }

    /** Returns the builder for the settings used for calls to listDeployments. */
    public UnaryCallSettings.Builder<ListDeploymentsRequest, ListDeploymentsResponse>
        listDeploymentsSettings() {
      return getStubSettingsBuilder().listDeploymentsSettings();
    }

    /** Returns the builder for the settings used for calls to updateDeployment. */
    public UnaryCallSettings.Builder<UpdateDeploymentRequest, Deployment>
        updateDeploymentSettings() {
      return getStubSettingsBuilder().updateDeploymentSettings();
    }

    /** Returns the builder for the settings used for calls to getPackage. */
    public UnaryCallSettings.Builder<GetPackageRequest, com.google.android.overtheair.v1.Package>
        getPackageSettings() {
      return getStubSettingsBuilder().getPackageSettings();
    }

    /** Returns the builder for the settings used for calls to listPackages. */
    public UnaryCallSettings.Builder<ListPackagesRequest, ListPackagesResponse>
        listPackagesSettings() {
      return getStubSettingsBuilder().listPackagesSettings();
    }

    /** Returns the builder for the settings used for calls to deletePackage. */
    public UnaryCallSettings.Builder<DeletePackageRequest, DeletePackageResponse>
        deletePackageSettings() {
      return getStubSettingsBuilder().deletePackageSettings();
    }

    /** Returns the builder for the settings used for calls to updatePackage. */
    public UnaryCallSettings.Builder<UpdatePackageRequest, com.google.android.overtheair.v1.Package>
        updatePackageSettings() {
      return getStubSettingsBuilder().updatePackageSettings();
    }

    /** Returns the builder for the settings used for calls to createConfig. */
    public UnaryCallSettings.Builder<CreateConfigRequest, Config> createConfigSettings() {
      return getStubSettingsBuilder().createConfigSettings();
    }

    /** Returns the builder for the settings used for calls to getConfig. */
    public UnaryCallSettings.Builder<GetConfigRequest, Config> getConfigSettings() {
      return getStubSettingsBuilder().getConfigSettings();
    }

    /** Returns the builder for the settings used for calls to listConfigs. */
    public UnaryCallSettings.Builder<ListConfigsRequest, ListConfigsResponse>
        listConfigsSettings() {
      return getStubSettingsBuilder().listConfigsSettings();
    }

    /** Returns the builder for the settings used for calls to deleteConfig. */
    public UnaryCallSettings.Builder<DeleteConfigRequest, DeleteConfigResponse>
        deleteConfigSettings() {
      return getStubSettingsBuilder().deleteConfigSettings();
    }

    /** Returns the builder for the settings used for calls to updateConfig. */
    public UnaryCallSettings.Builder<UpdateConfigRequest, Config> updateConfigSettings() {
      return getStubSettingsBuilder().updateConfigSettings();
    }

    /** Returns the builder for the settings used for calls to createGroup. */
    public UnaryCallSettings.Builder<CreateGroupRequest, Group> createGroupSettings() {
      return getStubSettingsBuilder().createGroupSettings();
    }

    /** Returns the builder for the settings used for calls to getGroup. */
    public UnaryCallSettings.Builder<GetGroupRequest, Group> getGroupSettings() {
      return getStubSettingsBuilder().getGroupSettings();
    }

    /** Returns the builder for the settings used for calls to listGroups. */
    public UnaryCallSettings.Builder<ListGroupsRequest, ListGroupsResponse> listGroupsSettings() {
      return getStubSettingsBuilder().listGroupsSettings();
    }

    /** Returns the builder for the settings used for calls to deleteGroup. */
    public UnaryCallSettings.Builder<DeleteGroupRequest, DeleteGroupResponse>
        deleteGroupSettings() {
      return getStubSettingsBuilder().deleteGroupSettings();
    }

    /** Returns the builder for the settings used for calls to updateGroup. */
    public UnaryCallSettings.Builder<UpdateGroupRequest, Group> updateGroupSettings() {
      return getStubSettingsBuilder().updateGroupSettings();
    }

    /** Returns the builder for the settings used for calls to disableGroups. */
    public UnaryCallSettings.Builder<DisableGroupsRequest, DisableGroupsResponse>
        disableGroupsSettings() {
      return getStubSettingsBuilder().disableGroupsSettings();
    }

    /** Returns the builder for the settings used for calls to enableGroups. */
    public UnaryCallSettings.Builder<EnableGroupsRequest, EnableGroupsResponse>
        enableGroupsSettings() {
      return getStubSettingsBuilder().enableGroupsSettings();
    }

    /** Returns the builder for the settings used for calls to createGroupMember. */
    public UnaryCallSettings.Builder<CreateGroupMemberRequest, GroupMember>
        createGroupMemberSettings() {
      return getStubSettingsBuilder().createGroupMemberSettings();
    }

    /** Returns the builder for the settings used for calls to createGroupMembers. */
    public UnaryCallSettings.Builder<CreateGroupMembersRequest, CreateGroupMembersResponse>
        createGroupMembersSettings() {
      return getStubSettingsBuilder().createGroupMembersSettings();
    }

    /** Returns the builder for the settings used for calls to getGroupMember. */
    public UnaryCallSettings.Builder<GetGroupMemberRequest, GroupMember> getGroupMemberSettings() {
      return getStubSettingsBuilder().getGroupMemberSettings();
    }

    /** Returns the builder for the settings used for calls to listGroupMembers. */
    public UnaryCallSettings.Builder<ListGroupMembersRequest, ListGroupMembersResponse>
        listGroupMembersSettings() {
      return getStubSettingsBuilder().listGroupMembersSettings();
    }

    /** Returns the builder for the settings used for calls to deleteGroupMember. */
    public UnaryCallSettings.Builder<DeleteGroupMemberRequest, DeleteGroupMemberResponse>
        deleteGroupMemberSettings() {
      return getStubSettingsBuilder().deleteGroupMemberSettings();
    }

    /** Returns the builder for the settings used for calls to deleteGroupMembers. */
    public UnaryCallSettings.Builder<DeleteGroupMembersRequest, DeleteGroupMembersResponse>
        deleteGroupMembersSettings() {
      return getStubSettingsBuilder().deleteGroupMembersSettings();
    }

    /** Returns the builder for the settings used for calls to getGroupChart. */
    public UnaryCallSettings.Builder<GetGroupChartRequest, Chart> getGroupChartSettings() {
      return getStubSettingsBuilder().getGroupChartSettings();
    }

    /** Returns the builder for the settings used for calls to listGroupCharts. */
    public UnaryCallSettings.Builder<ListGroupChartsRequest, ListGroupChartsResponse>
        listGroupChartsSettings() {
      return getStubSettingsBuilder().listGroupChartsSettings();
    }

    /** Returns the builder for the settings used for calls to listGroupConfigs. */
    public UnaryCallSettings.Builder<ListGroupConfigsRequest, ListGroupConfigsResponse>
        listGroupConfigsSettings() {
      return getStubSettingsBuilder().listGroupConfigsSettings();
    }

    /** Returns the builder for the settings used for calls to updateGroupConfigs. */
    public UnaryCallSettings.Builder<UpdateGroupConfigsRequest, UpdateGroupConfigsResponse>
        updateGroupConfigsSettings() {
      return getStubSettingsBuilder().updateGroupConfigsSettings();
    }

    /** Returns the builder for the settings used for calls to disableAllEnabledGroupsOfConfig. */
    public UnaryCallSettings.Builder<
            DisableAllEnabledGroupsOfConfigRequest, DisableAllEnabledGroupsOfConfigResponse>
        disableAllEnabledGroupsOfConfigSettings() {
      return getStubSettingsBuilder().disableAllEnabledGroupsOfConfigSettings();
    }

    /** Returns the builder for the settings used for calls to listConfigPackages. */
    public UnaryCallSettings.Builder<ListConfigPackagesRequest, ListConfigPackagesResponse>
        listConfigPackagesSettings() {
      return getStubSettingsBuilder().listConfigPackagesSettings();
    }

    /** Returns the builder for the settings used for calls to updateConfigPackages. */
    public UnaryCallSettings.Builder<UpdateConfigPackagesRequest, UpdateConfigPackagesResponse>
        updateConfigPackagesSettings() {
      return getStubSettingsBuilder().updateConfigPackagesSettings();
    }

    /** Returns the builder for the settings used for calls to listConfigsUsingPackage. */
    public UnaryCallSettings.Builder<
            ListConfigsUsingPackageRequest, ListConfigsUsingPackageResponse>
        listConfigsUsingPackageSettings() {
      return getStubSettingsBuilder().listConfigsUsingPackageSettings();
    }

    @Override
    public OverTheAirServiceSettings build() throws IOException {
      return new OverTheAirServiceSettings(this);
    }
  }
}
