/*
 * Copyright 2019 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.android.overtheair.spi.v1;

import com.google.android.overtheair.v1.Chart;
import com.google.android.overtheair.v1.ChartOptions;
import com.google.android.overtheair.v1.Config;
import com.google.android.overtheair.v1.CreateConfigRequest;
import com.google.android.overtheair.v1.CreateGroupMemberRequest;
import com.google.android.overtheair.v1.CreateGroupMembersRequest;
import com.google.android.overtheair.v1.CreateGroupMembersResponse;
import com.google.android.overtheair.v1.CreateGroupRequest;
import com.google.android.overtheair.v1.DeleteConfigRequest;
import com.google.android.overtheair.v1.DeleteConfigResponse;
import com.google.android.overtheair.v1.DeleteGroupMemberRequest;
import com.google.android.overtheair.v1.DeleteGroupMemberResponse;
import com.google.android.overtheair.v1.DeleteGroupMembersRequest;
import com.google.android.overtheair.v1.DeleteGroupMembersResponse;
import com.google.android.overtheair.v1.DeleteGroupRequest;
import com.google.android.overtheair.v1.DeleteGroupResponse;
import com.google.android.overtheair.v1.DeletePackageRequest;
import com.google.android.overtheair.v1.DeletePackageResponse;
import com.google.android.overtheair.v1.Deployment;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigRequest;
import com.google.android.overtheair.v1.DisableAllEnabledGroupsOfConfigResponse;
import com.google.android.overtheair.v1.DisableGroupsRequest;
import com.google.android.overtheair.v1.DisableGroupsResponse;
import com.google.android.overtheair.v1.EnableGroupsRequest;
import com.google.android.overtheair.v1.EnableGroupsResponse;
import com.google.android.overtheair.v1.GetConfigRequest;
import com.google.android.overtheair.v1.GetDeploymentRequest;
import com.google.android.overtheair.v1.GetGroupChartRequest;
import com.google.android.overtheair.v1.GetGroupMemberRequest;
import com.google.android.overtheair.v1.GetGroupRequest;
import com.google.android.overtheair.v1.GetPackageRequest;
import com.google.android.overtheair.v1.Group;
import com.google.android.overtheair.v1.GroupMember;
import com.google.android.overtheair.v1.ListConfigPackagesRequest;
import com.google.android.overtheair.v1.ListConfigPackagesResponse;
import com.google.android.overtheair.v1.ListConfigsRequest;
import com.google.android.overtheair.v1.ListConfigsResponse;
import com.google.android.overtheair.v1.ListConfigsUsingPackageRequest;
import com.google.android.overtheair.v1.ListConfigsUsingPackageResponse;
import com.google.android.overtheair.v1.ListDeploymentsRequest;
import com.google.android.overtheair.v1.ListDeploymentsResponse;
import com.google.android.overtheair.v1.ListGroupChartsRequest;
import com.google.android.overtheair.v1.ListGroupChartsResponse;
import com.google.android.overtheair.v1.ListGroupConfigsRequest;
import com.google.android.overtheair.v1.ListGroupConfigsResponse;
import com.google.android.overtheair.v1.ListGroupMembersRequest;
import com.google.android.overtheair.v1.ListGroupMembersResponse;
import com.google.android.overtheair.v1.ListGroupsRequest;
import com.google.android.overtheair.v1.ListGroupsResponse;
import com.google.android.overtheair.v1.ListPackagesRequest;
import com.google.android.overtheair.v1.ListPackagesResponse;
import com.google.android.overtheair.v1.PackageConfig;
import com.google.android.overtheair.v1.UpdateConfigPackagesRequest;
import com.google.android.overtheair.v1.UpdateConfigPackagesResponse;
import com.google.android.overtheair.v1.UpdateConfigRequest;
import com.google.android.overtheair.v1.UpdateDeploymentRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsRequest;
import com.google.android.overtheair.v1.UpdateGroupConfigsResponse;
import com.google.android.overtheair.v1.UpdateGroupRequest;
import com.google.android.overtheair.v1.UpdatePackageRequest;
import com.google.android.overtheair.v1.VersionTag;
import com.google.android.overtheair.v1.View;
import com.google.api.gax.core.NoCredentialsProvider;
import com.google.api.gax.grpc.GaxGrpcProperties;
import com.google.api.gax.grpc.testing.LocalChannelProvider;
import com.google.api.gax.grpc.testing.MockGrpcService;
import com.google.api.gax.grpc.testing.MockServiceHelper;
import com.google.api.gax.rpc.ApiClientHeaderProvider;
import com.google.api.gax.rpc.InvalidArgumentException;
import com.google.protobuf.AbstractMessage;
import io.grpc.Status;
import io.grpc.StatusRuntimeException;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import org.junit.After;
import org.junit.AfterClass;
import org.junit.Assert;
import org.junit.Before;
import org.junit.BeforeClass;
import org.junit.Test;

@javax.annotation.Generated("by GAPIC")
public class OverTheAirServiceClientTest {
  private static MockOverTheAirService mockOverTheAirService;
  private static MockServiceHelper serviceHelper;
  private OverTheAirServiceClient client;
  private LocalChannelProvider channelProvider;

  @BeforeClass
  public static void startStaticServer() {
    mockOverTheAirService = new MockOverTheAirService();
    serviceHelper =
        new MockServiceHelper(
            "in-process-1", Arrays.<MockGrpcService>asList(mockOverTheAirService));
    serviceHelper.start();
  }

  @AfterClass
  public static void stopServer() {
    serviceHelper.stop();
  }

  @Before
  public void setUp() throws IOException {
    serviceHelper.reset();
    channelProvider = serviceHelper.createChannelProvider();
    OverTheAirServiceSettings settings =
        OverTheAirServiceSettings.newBuilder()
            .setTransportChannelProvider(channelProvider)
            .setCredentialsProvider(NoCredentialsProvider.create())
            .build();
    client = OverTheAirServiceClient.create(settings);
  }

  @After
  public void tearDown() throws Exception {
    client.close();
  }

  @Test
  @SuppressWarnings("all")
  public void getDeploymentTest() {
    String name2 = "name2-1052831874";
    String description = "description-1724546052";
    int apiLevel = 81920737;
    String apfeProductId = "apfeProductId-1747882468";
    Deployment expectedResponse =
        Deployment.newBuilder()
            .setName(name2)
            .setDescription(description)
            .setApiLevel(apiLevel)
            .setApfeProductId(apfeProductId)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    View view = View.BASIC;

    Deployment actualResponse = client.getDeployment(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetDeploymentRequest actualRequest = (GetDeploymentRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getDeploymentExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      View view = View.BASIC;

      client.getDeployment(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listDeploymentsTest() {
    ListDeploymentsResponse expectedResponse = ListDeploymentsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    View view = View.BASIC;

    ListDeploymentsResponse actualResponse = client.listDeployments(view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListDeploymentsRequest actualRequest = (ListDeploymentsRequest) actualRequests.get(0);

    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listDeploymentsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      View view = View.BASIC;

      client.listDeployments(view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updateDeploymentTest() {
    String name2 = "name2-1052831874";
    String description = "description-1724546052";
    int apiLevel = 81920737;
    String apfeProductId = "apfeProductId-1747882468";
    Deployment expectedResponse =
        Deployment.newBuilder()
            .setName(name2)
            .setDescription(description)
            .setApiLevel(apiLevel)
            .setApfeProductId(apfeProductId)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    Deployment deployment = Deployment.newBuilder().build();
    VersionTag versionTag = VersionTag.newBuilder().build();

    Deployment actualResponse = client.updateDeployment(formattedName, deployment, versionTag);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdateDeploymentRequest actualRequest = (UpdateDeploymentRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(deployment, actualRequest.getDeployment());
    Assert.assertEquals(versionTag, actualRequest.getVersionTag());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updateDeploymentExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      Deployment deployment = Deployment.newBuilder().build();
      VersionTag versionTag = VersionTag.newBuilder().build();

      client.updateDeployment(formattedName, deployment, versionTag);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void getPackageTest() {
    String name2 = "name2-1052831874";
    String title = "title110371416";
    com.google.android.overtheair.v1.Package expectedResponse =
        com.google.android.overtheair.v1.Package.newBuilder()
            .setName(name2)
            .setTitle(title)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");
    View view = View.BASIC;

    com.google.android.overtheair.v1.Package actualResponse =
        client.getPackage(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetPackageRequest actualRequest = (GetPackageRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getPackageExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");
      View view = View.BASIC;

      client.getPackage(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listPackagesTest() {
    ListPackagesResponse expectedResponse = ListPackagesResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    View view = View.BASIC;

    ListPackagesResponse actualResponse = client.listPackages(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListPackagesRequest actualRequest = (ListPackagesRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listPackagesExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      View view = View.BASIC;

      client.listPackages(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void deletePackageTest() {
    DeletePackageResponse expectedResponse = DeletePackageResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");

    DeletePackageResponse actualResponse = client.deletePackage(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DeletePackageRequest actualRequest = (DeletePackageRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void deletePackageExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");

      client.deletePackage(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updatePackageTest() {
    String name2 = "name2-1052831874";
    String title = "title110371416";
    com.google.android.overtheair.v1.Package expectedResponse =
        com.google.android.overtheair.v1.Package.newBuilder()
            .setName(name2)
            .setTitle(title)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");
    com.google.android.overtheair.v1.Package packageObj =
        com.google.android.overtheair.v1.Package.newBuilder().build();
    VersionTag versionTag = VersionTag.newBuilder().build();

    com.google.android.overtheair.v1.Package actualResponse =
        client.updatePackage(formattedName, packageObj, versionTag);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdatePackageRequest actualRequest = (UpdatePackageRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(packageObj, actualRequest.getPackageObj());
    Assert.assertEquals(versionTag, actualRequest.getVersionTag());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updatePackageExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");
      com.google.android.overtheair.v1.Package packageObj =
          com.google.android.overtheair.v1.Package.newBuilder().build();
      VersionTag versionTag = VersionTag.newBuilder().build();

      client.updatePackage(formattedName, packageObj, versionTag);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void createConfigTest() {
    String name2 = "name2-1052831874";
    String title = "title110371416";
    String description = "description-1724546052";
    boolean updateBatteryAwareness = false;
    boolean updateRequiredSetup = false;
    boolean immediateRelease = false;
    boolean lowerCheckinInterval = false;
    boolean securityUpdate = true;
    Config expectedResponse =
        Config.newBuilder()
            .setName(name2)
            .setTitle(title)
            .setDescription(description)
            .setUpdateBatteryAwareness(updateBatteryAwareness)
            .setUpdateRequiredSetup(updateRequiredSetup)
            .setImmediateRelease(immediateRelease)
            .setLowerCheckinInterval(lowerCheckinInterval)
            .setSecurityUpdate(securityUpdate)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    Config config = Config.newBuilder().build();

    Config actualResponse = client.createConfig(formattedName, config);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    CreateConfigRequest actualRequest = (CreateConfigRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(config, actualRequest.getConfig());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void createConfigExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      Config config = Config.newBuilder().build();

      client.createConfig(formattedName, config);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void getConfigTest() {
    String name2 = "name2-1052831874";
    String title = "title110371416";
    String description = "description-1724546052";
    boolean updateBatteryAwareness = false;
    boolean updateRequiredSetup = false;
    boolean immediateRelease = false;
    boolean lowerCheckinInterval = false;
    boolean securityUpdate = true;
    Config expectedResponse =
        Config.newBuilder()
            .setName(name2)
            .setTitle(title)
            .setDescription(description)
            .setUpdateBatteryAwareness(updateBatteryAwareness)
            .setUpdateRequiredSetup(updateRequiredSetup)
            .setImmediateRelease(immediateRelease)
            .setLowerCheckinInterval(lowerCheckinInterval)
            .setSecurityUpdate(securityUpdate)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
    View view = View.BASIC;

    Config actualResponse = client.getConfig(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetConfigRequest actualRequest = (GetConfigRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getConfigExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
      View view = View.BASIC;

      client.getConfig(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigsTest() {
    ListConfigsResponse expectedResponse = ListConfigsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    View view = View.BASIC;

    ListConfigsResponse actualResponse = client.listConfigs(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListConfigsRequest actualRequest = (ListConfigsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      View view = View.BASIC;

      client.listConfigs(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void deleteConfigTest() {
    DeleteConfigResponse expectedResponse = DeleteConfigResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

    DeleteConfigResponse actualResponse = client.deleteConfig(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DeleteConfigRequest actualRequest = (DeleteConfigRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void deleteConfigExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

      client.deleteConfig(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updateConfigTest() {
    String name2 = "name2-1052831874";
    String title = "title110371416";
    String description = "description-1724546052";
    boolean updateBatteryAwareness = false;
    boolean updateRequiredSetup = false;
    boolean immediateRelease = false;
    boolean lowerCheckinInterval = false;
    boolean securityUpdate = true;
    Config expectedResponse =
        Config.newBuilder()
            .setName(name2)
            .setTitle(title)
            .setDescription(description)
            .setUpdateBatteryAwareness(updateBatteryAwareness)
            .setUpdateRequiredSetup(updateRequiredSetup)
            .setImmediateRelease(immediateRelease)
            .setLowerCheckinInterval(lowerCheckinInterval)
            .setSecurityUpdate(securityUpdate)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
    Config config = Config.newBuilder().build();
    VersionTag versionTag = VersionTag.newBuilder().build();

    Config actualResponse = client.updateConfig(formattedName, config, versionTag);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdateConfigRequest actualRequest = (UpdateConfigRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(config, actualRequest.getConfig());
    Assert.assertEquals(versionTag, actualRequest.getVersionTag());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updateConfigExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
      Config config = Config.newBuilder().build();
      VersionTag versionTag = VersionTag.newBuilder().build();

      client.updateConfig(formattedName, config, versionTag);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupTest() {
    String name2 = "name2-1052831874";
    boolean enabled = false;
    boolean bypassRolloutSchedule = true;
    Group expectedResponse =
        Group.newBuilder()
            .setName(name2)
            .setEnabled(enabled)
            .setBypassRolloutSchedule(bypassRolloutSchedule)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    Group group = Group.newBuilder().build();

    Group actualResponse = client.createGroup(formattedName, group);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    CreateGroupRequest actualRequest = (CreateGroupRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(group, actualRequest.getGroup());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      Group group = Group.newBuilder().build();

      client.createGroup(formattedName, group);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupTest() {
    String name2 = "name2-1052831874";
    boolean enabled = false;
    boolean bypassRolloutSchedule = true;
    Group expectedResponse =
        Group.newBuilder()
            .setName(name2)
            .setEnabled(enabled)
            .setBypassRolloutSchedule(bypassRolloutSchedule)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    View view = View.BASIC;

    Group actualResponse = client.getGroup(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetGroupRequest actualRequest = (GetGroupRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      View view = View.BASIC;

      client.getGroup(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupsTest() {
    ListGroupsResponse expectedResponse = ListGroupsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    View view = View.BASIC;

    ListGroupsResponse actualResponse = client.listGroups(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListGroupsRequest actualRequest = (ListGroupsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      View view = View.BASIC;

      client.listGroups(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupTest() {
    DeleteGroupResponse expectedResponse = DeleteGroupResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

    DeleteGroupResponse actualResponse = client.deleteGroup(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DeleteGroupRequest actualRequest = (DeleteGroupRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

      client.deleteGroup(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updateGroupTest() {
    String name2 = "name2-1052831874";
    boolean enabled = false;
    boolean bypassRolloutSchedule = true;
    Group expectedResponse =
        Group.newBuilder()
            .setName(name2)
            .setEnabled(enabled)
            .setBypassRolloutSchedule(bypassRolloutSchedule)
            .build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    Group group = Group.newBuilder().build();
    VersionTag versionTag = VersionTag.newBuilder().build();

    Group actualResponse = client.updateGroup(formattedName, group, versionTag);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdateGroupRequest actualRequest = (UpdateGroupRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(group, actualRequest.getGroup());
    Assert.assertEquals(versionTag, actualRequest.getVersionTag());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updateGroupExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      Group group = Group.newBuilder().build();
      VersionTag versionTag = VersionTag.newBuilder().build();

      client.updateGroup(formattedName, group, versionTag);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void disableGroupsTest() {
    DisableGroupsResponse expectedResponse = DisableGroupsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    List<String> groupNames = new ArrayList<>();

    DisableGroupsResponse actualResponse = client.disableGroups(formattedName, groupNames);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DisableGroupsRequest actualRequest = (DisableGroupsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(groupNames, actualRequest.getGroupNamesList());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void disableGroupsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      List<String> groupNames = new ArrayList<>();

      client.disableGroups(formattedName, groupNames);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void enableGroupsTest() {
    EnableGroupsResponse expectedResponse = EnableGroupsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
    List<String> groupNames = new ArrayList<>();

    EnableGroupsResponse actualResponse = client.enableGroups(formattedName, groupNames);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    EnableGroupsRequest actualRequest = (EnableGroupsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(groupNames, actualRequest.getGroupNamesList());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void enableGroupsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatDeploymentName("[DEPLOYMENT]");
      List<String> groupNames = new ArrayList<>();

      client.enableGroups(formattedName, groupNames);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupMemberTest() {
    String name2 = "name2-1052831874";
    GroupMember expectedResponse = GroupMember.newBuilder().setName(name2).build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    GroupMember groupMember = GroupMember.newBuilder().build();

    GroupMember actualResponse = client.createGroupMember(formattedName, groupMember);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    CreateGroupMemberRequest actualRequest = (CreateGroupMemberRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(groupMember, actualRequest.getGroupMember());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupMemberExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      GroupMember groupMember = GroupMember.newBuilder().build();

      client.createGroupMember(formattedName, groupMember);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupMembersTest() {
    CreateGroupMembersResponse expectedResponse = CreateGroupMembersResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    List<GroupMember> groupMembers = new ArrayList<>();

    CreateGroupMembersResponse actualResponse =
        client.createGroupMembers(formattedName, groupMembers);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    CreateGroupMembersRequest actualRequest = (CreateGroupMembersRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(groupMembers, actualRequest.getGroupMembersList());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void createGroupMembersExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      List<GroupMember> groupMembers = new ArrayList<>();

      client.createGroupMembers(formattedName, groupMembers);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupMemberTest() {
    String name2 = "name2-1052831874";
    GroupMember expectedResponse = GroupMember.newBuilder().setName(name2).build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatMemberName("[DEPLOYMENT]", "[GROUP]", "[MEMBER]");
    View view = View.BASIC;

    GroupMember actualResponse = client.getGroupMember(formattedName, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetGroupMemberRequest actualRequest = (GetGroupMemberRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupMemberExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatMemberName("[DEPLOYMENT]", "[GROUP]", "[MEMBER]");
      View view = View.BASIC;

      client.getGroupMember(formattedName, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupMembersTest() {
    ListGroupMembersResponse expectedResponse = ListGroupMembersResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

    ListGroupMembersResponse actualResponse = client.listGroupMembers(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListGroupMembersRequest actualRequest = (ListGroupMembersRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupMembersExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

      client.listGroupMembers(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupMemberTest() {
    DeleteGroupMemberResponse expectedResponse = DeleteGroupMemberResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatMemberName("[DEPLOYMENT]", "[GROUP]", "[MEMBER]");

    DeleteGroupMemberResponse actualResponse = client.deleteGroupMember(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DeleteGroupMemberRequest actualRequest = (DeleteGroupMemberRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupMemberExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatMemberName("[DEPLOYMENT]", "[GROUP]", "[MEMBER]");

      client.deleteGroupMember(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupMembersTest() {
    DeleteGroupMembersResponse expectedResponse = DeleteGroupMembersResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    List<GroupMember> groupMembers = new ArrayList<>();

    DeleteGroupMembersResponse actualResponse =
        client.deleteGroupMembers(formattedName, groupMembers);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DeleteGroupMembersRequest actualRequest = (DeleteGroupMembersRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(groupMembers, actualRequest.getGroupMembersList());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void deleteGroupMembersExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      List<GroupMember> groupMembers = new ArrayList<>();

      client.deleteGroupMembers(formattedName, groupMembers);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupChartTest() {
    String name2 = "name2-1052831874";
    Chart expectedResponse = Chart.newBuilder().setName(name2).build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatChartName("[DEPLOYMENT]", "[GROUP]", "[CHART]");
    ChartOptions options = ChartOptions.newBuilder().build();

    Chart actualResponse = client.getGroupChart(formattedName, options);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    GetGroupChartRequest actualRequest = (GetGroupChartRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(options, actualRequest.getOptions());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void getGroupChartExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatChartName("[DEPLOYMENT]", "[GROUP]", "[CHART]");
      ChartOptions options = ChartOptions.newBuilder().build();

      client.getGroupChart(formattedName, options);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupChartsTest() {
    ListGroupChartsResponse expectedResponse = ListGroupChartsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    ChartOptions options = ChartOptions.newBuilder().build();
    View view = View.BASIC;

    ListGroupChartsResponse actualResponse = client.listGroupCharts(formattedName, options, view);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListGroupChartsRequest actualRequest = (ListGroupChartsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(options, actualRequest.getOptions());
    Assert.assertEquals(view, actualRequest.getView());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupChartsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      ChartOptions options = ChartOptions.newBuilder().build();
      View view = View.BASIC;

      client.listGroupCharts(formattedName, options, view);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupConfigsTest() {
    ListGroupConfigsResponse expectedResponse = ListGroupConfigsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

    ListGroupConfigsResponse actualResponse = client.listGroupConfigs(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListGroupConfigsRequest actualRequest = (ListGroupConfigsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listGroupConfigsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");

      client.listGroupConfigs(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updateGroupConfigsTest() {
    UpdateGroupConfigsResponse expectedResponse = UpdateGroupConfigsResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
    List<String> configNames = new ArrayList<>();
    VersionTag versionTag = VersionTag.newBuilder().build();

    UpdateGroupConfigsResponse actualResponse =
        client.updateGroupConfigs(formattedName, configNames, versionTag);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdateGroupConfigsRequest actualRequest = (UpdateGroupConfigsRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(configNames, actualRequest.getConfigNamesList());
    Assert.assertEquals(versionTag, actualRequest.getVersionTag());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updateGroupConfigsExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatGroupName("[DEPLOYMENT]", "[GROUP]");
      List<String> configNames = new ArrayList<>();
      VersionTag versionTag = VersionTag.newBuilder().build();

      client.updateGroupConfigs(formattedName, configNames, versionTag);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void disableAllEnabledGroupsOfConfigTest() {
    DisableAllEnabledGroupsOfConfigResponse expectedResponse =
        DisableAllEnabledGroupsOfConfigResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

    DisableAllEnabledGroupsOfConfigResponse actualResponse =
        client.disableAllEnabledGroupsOfConfig(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    DisableAllEnabledGroupsOfConfigRequest actualRequest =
        (DisableAllEnabledGroupsOfConfigRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void disableAllEnabledGroupsOfConfigExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

      client.disableAllEnabledGroupsOfConfig(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigPackagesTest() {
    ListConfigPackagesResponse expectedResponse = ListConfigPackagesResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

    ListConfigPackagesResponse actualResponse = client.listConfigPackages(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListConfigPackagesRequest actualRequest = (ListConfigPackagesRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigPackagesExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");

      client.listConfigPackages(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void updateConfigPackagesTest() {
    UpdateConfigPackagesResponse expectedResponse =
        UpdateConfigPackagesResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
    List<PackageConfig> packageConfigs = new ArrayList<>();

    UpdateConfigPackagesResponse actualResponse =
        client.updateConfigPackages(formattedName, packageConfigs);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    UpdateConfigPackagesRequest actualRequest = (UpdateConfigPackagesRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertEquals(packageConfigs, actualRequest.getPackageConfigsList());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void updateConfigPackagesExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName = OverTheAirServiceClient.formatConfigName("[DEPLOYMENT]", "[CONFIG]");
      List<PackageConfig> packageConfigs = new ArrayList<>();

      client.updateConfigPackages(formattedName, packageConfigs);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigsUsingPackageTest() {
    ListConfigsUsingPackageResponse expectedResponse =
        ListConfigsUsingPackageResponse.newBuilder().build();
    mockOverTheAirService.addResponse(expectedResponse);

    String formattedName =
        OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");

    ListConfigsUsingPackageResponse actualResponse = client.listConfigsUsingPackage(formattedName);
    Assert.assertEquals(expectedResponse, actualResponse);

    List<AbstractMessage> actualRequests = mockOverTheAirService.getRequests();
    Assert.assertEquals(1, actualRequests.size());
    ListConfigsUsingPackageRequest actualRequest =
        (ListConfigsUsingPackageRequest) actualRequests.get(0);

    Assert.assertEquals(formattedName, actualRequest.getName());
    Assert.assertTrue(
        channelProvider.isHeaderSent(
            ApiClientHeaderProvider.getDefaultApiClientHeaderKey(),
            GaxGrpcProperties.getDefaultApiClientHeaderPattern()));
  }

  @Test
  @SuppressWarnings("all")
  public void listConfigsUsingPackageExceptionTest() throws Exception {
    StatusRuntimeException exception = new StatusRuntimeException(Status.INVALID_ARGUMENT);
    mockOverTheAirService.addException(exception);

    try {
      String formattedName =
          OverTheAirServiceClient.formatPackagePathName("[DEPLOYMENT]", "[PACKAGE_PATH]");

      client.listConfigsUsingPackage(formattedName);
      Assert.fail("No exception raised");
    } catch (InvalidArgumentException e) {
      // Expected exception
    }
  }
}
